[xiph-commits] r13271 - trunk/icebreaker
nickmudd at svn.xiph.org
nickmudd at svn.xiph.org
Sun Jul 15 17:24:50 PDT 2007
Author: nickmudd
Date: 2007-07-15 17:24:50 -0700 (Sun, 15 Jul 2007)
New Revision: 13271
Modified:
trunk/icebreaker/icebreaker.py
Log:
played around with icebreaker.py a bit
Modified: trunk/icebreaker/icebreaker.py
===================================================================
--- trunk/icebreaker/icebreaker.py 2007-07-15 19:16:21 UTC (rev 13270)
+++ trunk/icebreaker/icebreaker.py 2007-07-16 00:24:50 UTC (rev 13271)
@@ -50,16 +50,20 @@
#check playlists table for list
# make days in columns
# time in tuples per playlist
n=datetime.now().strftime("%H:%M")
- s = #time from playlists
+ start = #time from playlists :: compare to current time, use timedelta
+ stop = #time from playlists :: find way to make it stick
# convert string time to real time object
- f=datetime.time(datetime(*strptime(s, "%H:%M")[0:6])).strftime("%H:%M")
+ start1=datetime.time(datetime(*strptime(start, "%H:%M")[0:6])).strftime("%H:%M")
+ stop1=datetime.time(datetime(*strptime(stop, "%H:%M")[0:6])).strftime("%H:%M")
+ # set a boolean to 'list'
- # use timedelta
- #if no list
+ #### Move this to list script
+ #if list not true
# shuffle from files
+
#change 0 for current list to 1
More information about the commits
mailing list
@@ -50,16 +50,20 @@
#check playlists table for list
# make days in columns
- # time in tuples per playlist
+ # time in tuples per playlist :: make in [start:stop],[start:stop] form?
n=datetime.now().strftime("%H:%M")